==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/parse/bean/InvoiceInfoRuleDTO.java <==
package com.xforceplus.seller.config.client.parse.bean;/**
 * Created by admin on 2018/10/16.
 */

import com.xforceplus.seller.config.client.parse.BaseRuleBean;
import io.swagger.annotations.ApiModelProperty;

/**
 * @Author zzw
 * @Description 票面规则
 * @Date
 * @return
 **/
public class InvoiceInfoRuleDTO extends BaseRuleBean {
    @ApiModelProperty("银行名称")
    private String purchaserBankName;
    @ApiModelProperty("地址")
    private String purchaserAddress;
    @ApiModelProperty("银行账号")
    private String purchaserBankAccount;
    @ApiModelProperty("电话")
    private String purchaserTel;

    @ApiModelProperty("银行名称")
    private String sellerBankName;
    @ApiModelProperty("地址")
    private String sellerAddress;
    @ApiModelProperty("银行账号")
    private String sellerBankAccount;
    @ApiModelProperty("电话")
    private String sellerTel;
    @ApiModelProperty("收款人姓名")
    private String cashierName;
    @ApiModelProperty("审核人姓名")
    private String checkerName;
    @ApiModelProperty("开平人姓名")
    private String invoicerName;


    public String getPurchaserBankName() {
        return purchaserBankName;
    }

    public void setPurchaserBankName(String purchaserBankName) {
        this.purchaserBankName = purchaserBankName;
    }

    public String getPurchaserAddress() {
        return purchaserAddress;
    }

    public void setPurchaserAddress(String purchaserAddress) {
        this.purchaserAddress = purchaserAddress;
    }

    public String getPurchaserBankAccount() {
        return purchaserBankAccount;
    }

    public void setPurchaserBankAccount(String purchaserBankAccount) {
        this.purchaserBankAccount = purchaserBankAccount;
    }

    public String getPurchaserTel() {
        return purchaserTel;
    }

    public void setPurchaserTel(String purchaserTel) {
        this.purchaserTel = purchaserTel;
    }

    public String getCashierName() {
        return cashierName;
    }

    public void setCashierName(String cashierName) {
        this.cashierName = cashierName;
    }

    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }

    public String getInvoicerName() {
        return invoicerName;
    }

    public void setInvoicerName(String invoicerName) {
        this.invoicerName = invoicerName;
    }

    public String getSellerBankName() {
        return sellerBankName;
    }

    public void setSellerBankName(String sellerBankName) {
        this.sellerBankName = sellerBankName;
    }

    public String getSellerAddress() {
        return sellerAddress;
    }

    public void setSellerAddress(String sellerAddress) {
        this.sellerAddress = sellerAddress;
    }

    public String getSellerBankAccount() {
        return sellerBankAccount;
    }

    public void setSellerBankAccount(String sellerBankAccount) {
        this.sellerBankAccount = sellerBankAccount;
    }

    public String getSellerTel() {
        return sellerTel;
    }

    public void setSellerTel(String sellerTel) {
        this.sellerTel = sellerTel;
    }

    @Override
    public String toString() {
        return "InvoiceInfoRuleDTO{" +
                "purchaserBankName='" + purchaserBankName + '\'' +
                ", purchaserAddress='" + purchaserAddress + '\'' +
                ", purchaserBankAccount='" + purchaserBankAccount + '\'' +
                ", purchaserTel='" + purchaserTel + '\'' +
                ", sellerBankName='" + sellerBankName + '\'' +
                ", sellerAddress='" + sellerAddress + '\'' +
                ", sellerBankAccount='" + sellerBankAccount + '\'' +
                ", sellerTel='" + sellerTel + '\'' +
                ", cashierName='" + cashierName + '\'' +
                ", checkerName='" + checkerName + '\'' +
                ", invoicerName='" + invoicerName + '\'' +
                '}';
    }
}

==> seller-config-client-api-4.1.30-20250928.033323-2-sources.jar: com/xforceplus/seller/config/client/parse/bean/InvoiceInfoRuleDTO.java <==
package com.xforceplus.seller.config.client.parse.bean;/**
 * Created by admin on 2018/10/16.
 */

import com.xforceplus.seller.config.client.parse.BaseRuleBean;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * @Author zzw
 * @Description 票面规则
 * @Date
 * @return
 **/
public class InvoiceInfoRuleDTO extends BaseRuleBean implements Serializable {
    @ApiModelProperty("银行名称")
    private String purchaserBankName;
    @ApiModelProperty("地址")
    private String purchaserAddress;
    @ApiModelProperty("银行账号")
    private String purchaserBankAccount;
    @ApiModelProperty("电话")
    private String purchaserTel;

    @ApiModelProperty("银行名称")
    private String sellerBankName;
    @ApiModelProperty("地址")
    private String sellerAddress;
    @ApiModelProperty("银行账号")
    private String sellerBankAccount;
    @ApiModelProperty("电话")
    private String sellerTel;
    @ApiModelProperty("收款人姓名")
    private String cashierName;
    @ApiModelProperty("审核人姓名")
    private String checkerName;
    @ApiModelProperty("开平人姓名")
    private String invoicerName;


    public String getPurchaserBankName() {
        return purchaserBankName;
    }

    public void setPurchaserBankName(String purchaserBankName) {
        this.purchaserBankName = purchaserBankName;
    }

    public String getPurchaserAddress() {
        return purchaserAddress;
    }

    public void setPurchaserAddress(String purchaserAddress) {
        this.purchaserAddress = purchaserAddress;
    }

    public String getPurchaserBankAccount() {
        return purchaserBankAccount;
    }

    public void setPurchaserBankAccount(String purchaserBankAccount) {
        this.purchaserBankAccount = purchaserBankAccount;
    }

    public String getPurchaserTel() {
        return purchaserTel;
    }

    public void setPurchaserTel(String purchaserTel) {
        this.purchaserTel = purchaserTel;
    }

    public String getCashierName() {
        return cashierName;
    }

    public void setCashierName(String cashierName) {
        this.cashierName = cashierName;
    }

    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }

    public String getInvoicerName() {
        return invoicerName;
    }

    public void setInvoicerName(String invoicerName) {
        this.invoicerName = invoicerName;
    }

    public String getSellerBankName() {
        return sellerBankName;
    }

    public void setSellerBankName(String sellerBankName) {
        this.sellerBankName = sellerBankName;
    }

    public String getSellerAddress() {
        return sellerAddress;
    }

    public void setSellerAddress(String sellerAddress) {
        this.sellerAddress = sellerAddress;
    }

    public String getSellerBankAccount() {
        return sellerBankAccount;
    }

    public void setSellerBankAccount(String sellerBankAccount) {
        this.sellerBankAccount = sellerBankAccount;
    }

    public String getSellerTel() {
        return sellerTel;
    }

    public void setSellerTel(String sellerTel) {
        this.sellerTel = sellerTel;
    }

    @Override
    public String toString() {
        return "InvoiceInfoRuleDTO{" +
                "purchaserBankName='" + purchaserBankName + '\'' +
                ", purchaserAddress='" + purchaserAddress + '\'' +
                ", purchaserBankAccount='" + purchaserBankAccount + '\'' +
                ", purchaserTel='" + purchaserTel + '\'' +
                ", sellerBankName='" + sellerBankName + '\'' +
                ", sellerAddress='" + sellerAddress + '\'' +
                ", sellerBankAccount='" + sellerBankAccount + '\'' +
                ", sellerTel='" + sellerTel + '\'' +
                ", cashierName='" + cashierName + '\'' +
                ", checkerName='" + checkerName + '\'' +
                ", invoicerName='" + invoicerName + '\'' +
                '}';
    }
}
